@@ -15,7 +15,7 @@ class ProgressBar:
     """
 
     def __init__(self, in_loop, bar_length: int = 40, start_mark: str = None, finish_mark='progress done!',
-                 max: int = None, total: int = None, detail_func: callable = None):
+                 max: int = None, total: int = None, detail_func: callable = None, remove_last: bool = False, smoothing: int = None):
         """
         The initial function
         :param in_loop: the input loop
@@ -24,19 +24,18 @@ class ProgressBar:
         :param finish_mark: print string what you want when progress finish
         :param total: total value. If you do not fill this, it will calculate automatically, but it may be slow
         :param detail_func: write detail using detail_func
+        :param remove_last: if True, remove progressbar when process is end
+        :param smoothing: make stable when estimate time taking
         """
 
         print(start_mark) if start_mark is not None else None
 
-        self.take = np.zeros(10, float)
-        T = time.time()
-        for i in range(10): self.take[i] = T
-
         self.start = time.time() * 1000  # for the total take time
         self.bar_length = bar_length
         self.finish_mark = finish_mark
         self.index = 0
         self.detail_func = detail_func
+        self.remove_last = remove_last
 
         self.it = iter([i for i in range(in_loop)]) if type(in_loop) == int else iter(in_loop)
 
@@ -49,6 +48,11 @@ class ProgressBar:
             self.length = 0
             for _ in iter(copy_it): self.length = self.length + 1
 
+        self.smoothing = self.length // 100 if smoothing is None else smoothing
+        self.take = np.zeros(self.smoothing, float)
+        T = time.time()
+        for i in range(self.smoothing): self.take[i] = T
+
     def __iter__(self):
         return self
 
@@ -57,6 +61,8 @@ class ProgressBar:
             print(f'\r\033[2K|{bar}{space}| \033[38;5;208m{progress_per_str}%\033[0m |'
                   f' \033[38;5;177m{self.index}/{self.length}\033[0m | \033[38;5;43m{left}\033[0m\033[0m |'
                   f' {self.detail_func(out)} |', end='')
+        elif end and self.remove_last:
+            print('\r', end='\r')
         else:
             print(f'\r\033[2K|{bar}{space}| \033[38;5;208m{progress_per_str}%\033[0m |'
                   f' \033[38;5;177m{self.index}/{self.length}\033[0m | \033[38;5;43m{left}\033[0m\033[0m |', end='')
@@ -86,12 +92,12 @@ class ProgressBar:
                 # The first loop is not finished yet, so that it cannot be calculated
                 left = '...'
             else:
-                take_temp = np.zeros(10, float)
-                take_temp[:9] = self.take[1:10]
-                take_temp[9] = time.time()
+                take_temp = np.zeros(self.smoothing, float)
+                take_temp[:self.smoothing - 1] = self.take[1:self.smoothing]
+                take_temp[self.smoothing - 1] = time.time()
 
                 # make time smooth
-                if self.index >= 10:
+                if self.index >= self.smoothing:
                     left = np.mean(take_temp - self.take) * (self.length - self.index)
                 else:
                     left = np.sum(take_temp - self.take) * (self.length - self.index) / self.index
